@@ -2179,4 +2179,21 @@ if (.runThisTest) {
 
     }
 
+    ## 21 July 2018
+    ## min/max
+    test.sugar.min.max <- function() {
+        # min(empty) gives NA for integer, Inf for numeric (#844)
+        checkTrue(is.na(intmin(integer(0))),    "min(integer(0))")
+        checkEquals(doublemin(numeric(0)), Inf, "min(numeric(0))")
+
+        # max(empty_ gives NA for integer, Inf for numeric (#844)
+        checkTrue(is.na(intmax(integer(0))),     "max(integer(0))")
+        checkEquals(doublemax(numeric(0)), -Inf, "max(numeric(0))")
+
+        # 'normal' values
+        checkEquals(intmin(c(1:10)),        1L,   "min(integer(...))")
+        checkEquals(doublemin(1.0*c(1:10)), 1.0,  "min(numeric(...))")
+        checkEquals(intmax(c(1:10)),        10L,  "min(integer(...))")
+        checkEquals(doublemax(1.0*c(1:10)), 10.0, "min(numeric(...))")
+    }
 }
